(function() {

  describe("Format Month", function() {
    return it("takes a 3 letter month and returns the correct JS index", function() {
      this.verbose_month = "Mar";
      this.month = new FormatMonth(this.verbose_month);
      return (expect(this.month.toIndex())).toEqual(2);
    });
  });

  describe("Format Time", function() {
    it("takes hours and minutes and returns a formated time", function() {
      this.time = new FormatTime(19, 30);
      return (expect(this.time.toFriendly())).toEqual("7:30pm");
    });
    it("handles 00 minutes correctly", function() {
      this.time = new FormatTime('00', 00);
      return (expect(this.time.minutes)).toEqual(00);
    });
    it("handles 00 hours correctly", function() {
      this.time = new FormatTime('00', 00);
      return (expect(this.time.hour)).toEqual('00');
    });
    it("handles 01 hours correctly", function() {
      this.time = new FormatTime('01', 00);
      return (expect(this.time.hour)).toEqual('01');
    });
    it("handles 00:00 correctly", function() {
      this.time = new FormatTime('00', 00);
      return (expect(this.time.toFriendly())).toEqual("12am");
    });
    return it("handles 01:00 correctly", function() {
      this.time = new FormatTime('01', 00);
      return (expect(this.time.toFriendly())).toEqual("1am");
    });
  });

  describe("Friendly", function() {
    it("knows it's today", function() {
      this.today = new Date();
      this.date = new Friendly(this.today);
      return (expect(this.date.toFriendly())).toEqual("Today");
    });
    it("knows it's yesterday", function() {
      this.today = new Date();
      this.yesterday = new Date(this.today.getTime() - 86400000);
      this.date = new Friendly(this.yesterday);
      return (expect(this.date.toFriendly())).toEqual("Yesterday");
    });
    it("knows it's tomorrow", function() {
      this.today = new Date();
      this.tomorrow = new Date(this.today.getTime() + 86400000);
      this.date = new Friendly(this.tomorrow);
      return (expect(this.date.toFriendly())).toEqual("Tomorrow");
    });
    return it("can friendly format a date far in the future", function() {
      this.distant_date = new Date(2020, 03, 30);
      this.date = new Friendly(this.distant_date);
      return (expect(this.date.toFriendly())).toEqual("Thursday the 30th of April 2020");
    });
  });

  describe("StdDate", function() {
    beforeEach(function() {
      this.date = new Date(2020, 02, 31, 19, 30);
      return this.date = new StdDate(this.date);
    });
    it("extracts day", function() {
      return (expect(this.date.day)).toEqual('31');
    });
    it("extracts month", function() {
      return (expect(this.date.month)).toEqual(2);
    });
    it("extracts year", function() {
      return (expect(this.date.year)).toEqual('2020');
    });
    it("extracts time", function() {
      return (expect(this.date.time)).toEqual('7:30pm');
    });
    it("parses day, month and year into a JS date object", function() {
      this.our_date = new Date(2020, 02, 31);
      return (expect(this.date.date.date)).toEqual(this.our_date);
    });
    it("returns a friendly version of the distant date", function() {
      return (expect(this.date.toFriendly())).toEqual("Tuesday the 31st of March 2020 at 7:30pm");
    });
    it("returns both formats as JSON", function() {
      return (expect(this.date.toJSON())).toEqual({
        friendly_date: 'Tuesday the 31st of March 2020 at 7:30pm',
        js_date: 'Tue Mar 31 2020 19:30:00'
      });
    });
    it("handles 00 hours correctly", function() {
      this.date = 'Thu Apr 30 2020 00:00:00 GMT+0100 (BST)';
      this.date = new StdDate(this.date);
      return (expect(this.date.hour)).toEqual('00');
    });
    it("handles 00:00 correctly", function() {
      this.date = 'Thu Apr 30 2020 00:00:00 GMT+0100 (BST)';
      this.date = new StdDate(this.date);
      return (expect(this.date.time)).toEqual('12am');
    });
    return it("can go from stdDate to Friendly date and back to stdDate again", function() {
      this.js_date = 'Tue Mar 31 2020 19:30:00';
      this.date = new StdDate('Tue Mar 31 2020 19:30:00');
      this.friendly_date = this.date.toFriendly();
      this.date = new FriendlyDate(this.friendly_date);
      return (expect(this.date.toJS())).toEqual(this.js_date);
    });
  });

  describe("FriendlyDate", function() {
    beforeEach(function() {
      this.date = "Tuesday the 31st of March 2020 at 7:30pm";
      this.jsDate = "Tue Mar 31 2020 19:30:00";
      this.date = new FriendlyDate(this.date);
      return this.pattern = /(.*)(\d{2}:\d{2}:\d{2}).*/;
    });
    it("splits up the date", function() {
      return (expect(this.date.date)).toEqual("Tuesday the 31st of March 2020");
    });
    it("extracts the verbose day", function() {
      return (expect(this.date.verbose_day)).toEqual("Tuesday");
    });
    it("converts hours, minutes and period into JSTime", function() {
      return (expect(this.date.time)).toEqual("19:30:00");
    });
    it("converts friendly date to JS date", function() {
      return (expect(this.date.toJS())).toEqual(this.jsDate);
    });
    it("returns both formats as JSON", function() {
      return (expect(this.date.toJSON())).toEqual({
        friendly_date: 'Tuesday the 31st of March 2020 at 7:30pm',
        js_date: 'Tue Mar 31 2020 19:30:00'
      });
    });
    it("returns correct JS if an hour like 12am", function() {
      this.date = "Tuesday the 31st of March 2020 at 12am";
      this.date = new FriendlyDate(this.date);
      return (expect(this.date.time)).toEqual("00:00:00");
    });
    it("returns the correct JS if today", function() {
      var all, date, time, _ref;
      this.date = "Today at 12pm";
      this.date = new FriendlyDate(this.date);
      this.today = new Date();
      this.today.setHours(12, 0, 0, 0);
      _ref = this.today.toString().match(this.pattern), all = _ref[0], date = _ref[1], time = _ref[2];
      this.today = "" + date + " " + time;
      return (expect(this.date.toJS())).toEqual(this.today);
    });
    it("returns the correct JS if yesterday", function() {
      var all, date, time, _ref;
      this.date = "Yesterday at 12pm";
      this.date = new FriendlyDate(this.date);
      this.today = new Date();
      this.yesterday = new Date(this.today.getTime() - 86400000);
      this.yesterday.setHours(12, 0, 0, 0);
      _ref = this.yesterday.toString().match(this.pattern), all = _ref[0], date = _ref[1], time = _ref[2];
      this.yesterday = "" + date + " " + time;
      return (expect(this.date.toJS())).toEqual(this.yesterday);
    });
    return it("returns the correct JS if tomorrow", function() {
      var all, date, time, _ref;
      this.date = "Tomorrow at 12pm";
      this.date = new FriendlyDate(this.date);
      this.today = new Date();
      this.tomorrow = new Date(this.today.getTime() + 86400000);
      this.tomorrow.setHours(12, 0, 0, 0);
      _ref = this.tomorrow.toString().match(this.pattern), all = _ref[0], date = _ref[1], time = _ref[2];
      this.tomorrow = "" + date + " " + time;
      return (expect(this.date.toJS())).toEqual(this.tomorrow);
    });
  });

  describe("JSTime", function() {
    it("converts friendly time to std JS time", function() {
      this.time = new FormatJSTime("7", "30", "pm");
      return (expect(this.time.toJS())).toEqual("19:30:00");
    });
    return it("converts 12am style times back to JS time", function() {
      this.time = new FormatJSTime("7", "pm");
      return (expect(this.time.toJS())).toEqual("19:00:00");
    });
  });

}).call(this);
